<?php
/*
Plugin Name: Contact Form 7 - Dynamic Echo Extension
Plugin URI: http://daily.glocalism.jp/wordpress/contact-form-7-dynamic-echo/
Description: Simply 'echo's a dynamic field that accepts any shortcode to generate the content.  Requires Contact Form 7 and Contact Form 7 Dynamic Extension. 
Version: 1.1
Author: Yusuke Kawato, GLOCALISM Inc.
Author URI: http://glocalism.co.jp
License: GPL2
*/

/*  Copyright 2010-2013  Yusuke Kawato, GLOCALISM Inc. (email : ykawato@glocalism.jp)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


/**
 ** A base module for [dynamicecho]
 **/
function wpcf7_dynamicecho_init(){
	if(function_exists('wpcf7_add_shortcode')){

		/* Shortcode handler */		
		wpcf7_add_shortcode( 'dynamicecho', 'wpcf7_dynamicecho_shortcode_handler', true );

	}
		
	add_action( 'admin_init', 'wpcf7_add_tag_generator_dynamicecho', 15 );
	
}

#add_action( 'plugins_loaded', 'wpcf7_dynamicecho_init');
add_action( 'init', 'wpcf7_dynamicecho_init');


/*************************************************************
 * dynamicecho Shortcode
 *************************************************************/
function wpcf7_dynamicecho_shortcode_handler( $tag ) {
	global $wpcf7_contact_form;

	if ( ! is_array( $tag ) )
		return '';

	$type = $tag['type'];
	$name = $tag['name'];
	$options = (array) $tag['options'];
	$values = (array) $tag['values'];

	if ( empty( $name ) )
		return '';

	$atts = '';
	$id_att = '';
	$class_att = '';
	$size_att = '';
	$maxlength_att = '';
	$tabindex_att = '';

	$class_att .= ' wpcf7-text';

	foreach ( $options as $option ) {
		if ( preg_match( '%^id:([-0-9a-zA-Z_]+)$%', $option, $matches ) ) {
			$id_att = $matches[1];
		}
	}

	if ( $id_att )
		$atts .= ' id="' . trim( $id_att ) . '"';

	// Value
	if ( is_a( $wpcf7_contact_form, 'WPCF7_ContactForm' ) && $wpcf7_contact_form->is_posted() ) {
		if ( isset( $_POST['_wpcf7_mail_sent'] ) && $_POST['_wpcf7_mail_sent']['ok'] )
			$value = '';
		else
			$value = stripslashes_deep( $_POST[$name] );
	} else {
		$value = isset( $values[0] ) ? $values[0] : '';
	}
	
	$scval = do_shortcode('['.$value.']');
	if($scval != '['.$value.']') $value = $scval;
	//echo '<pre>'; print_r($options);echo '</pre>';
	
	$html = esc_attr( $value );

	//No need to validate, it's a hidden field - we could validate by checking the value hasn't changed, but that seems overkill I think
	//$validation_error = '';
	//if ( is_a( $wpcf7_contact_form, 'WPCF7_ContactForm' ) )
	//	$validation_error = $wpcf7_contact_form->validation_error( $name );

	$html = '<span class="wpcf7-form-control-wrap ' . $name . '">' . $html . $validation_error . '</span>';

	return $html;
}


/* Tag generator */

function wpcf7_add_tag_generator_dynamicecho() {
	if(function_exists('wpcf7_add_tag_generator')){
		wpcf7_add_tag_generator( 'dynamicecho', __( 'Dynamic Echo', 'wpcf7' ),
			'wpcf7-tg-pane-dynamicecho', 'wpcf7_tg_pane_dynamicecho_' );
	}
}

function wpcf7_tg_pane_dynamicecho_( &$contact_form ) {
	wpcf7_tg_pane_dynamicecho( 'dynamicecho' );
}

function wpcf7_tg_pane_dynamicecho( $type = 'dynamicecho' ) {
?>
<div id="wpcf7-tg-pane-<?php echo $type; ?>" class="hidden">
<form action="">
<table>
<tr><td><?php echo esc_html( __( 'Name', 'wpcf7' ) ); ?><br /><input type="text" name="name" class="tg-name oneline" /></td><td></td></tr>
</table>

<table>

<tr>

<td><?php echo esc_html( __( 'Dynamic value', 'wpcf7' ) ); ?> (<?php echo esc_html( __( 'optional', 'wpcf7' ) ); ?>)<br /><input type="text" name="values" class="oneline" />
<?php echo esc_html( __( 'You can enter any short code.  Just leave out the square brackets ([]) and only use single quotes (\' not ")', 'wpcf7' )); ?>
</td>
</tr>
</table>

<div class="tg-tag"><?php echo esc_html( __( "Copy this code and paste it into the form left.", 'wpcf7' ) ); ?><br /><input type="text" name="<?php echo $type; ?>" class="tag" readonly="readonly" onfocus="this.select()" /></div>

</form>
</div>
<?php
}
